@@ -3,6 +3,7 @@ from subprocess import run
 from pathlib import Path
 import click
 import json
+import os
 from making_with_code_cli.helpers import cd
 from making_with_code_cli.styles import (
     confirm,
@@ -41,15 +42,35 @@ class GithubBackend(GitBackend):
     def init_create_from_template(self, module, modpath):
         """Creates the named repo from a template, or clones an existing repo with. 
         """
-        repo_name = modpath.name
+        repo_name = self.get_repo_name_from_template_repo_url(module["repo_url"])
+        url = module["repo_url"]
+
         if self.user_has_repo(repo_name):
-            cmd = f'gh repo clone "{repo_name}" "{modpath.name}"'
+            cmd = f'gh repo clone "{url}" "{modpath.name}"'
         else:
-            url = module["repo_url"]
-            cmd = f'gh repo create "{repo_name}" --clone --private --template "{url}"'
+            if modpath.exists():
+                self.relocate_existing_directory(modpath)
+            cmd = f'gh repo create "{modpath.name}" --clone --private --remote {repo_name} --template "{url}"'
         with cd(modpath.parent):
             run(cmd, shell=True, check=True)
 
+    def get_repo_name_from_template_repo_url(self, url):
+        """Parses the template repo URL and returns the name of a repo to create.
+        Expects a GitHub url like "https://github.com/cproctor/mwc-pedprog-unit00-project-drawing.git"
+        """
+        parts = url.split('/')
+        name, suffix = parts[-1][:-4], parts[-1][-4:]
+        return name
+
+    def relocate_existing_directory(self, path):
+        """Moves an existing directory out of the way.
+        """
+        new_path = path.parent / path.name + '_old'
+        while new_path.exists():
+            new_path = new_path.parent / new_path.name + '_old'
+        click.echo(confirm(f"Moving existing directory {path} to {new_path}."))
+        os.rename(path, new_path)
+
     def user_has_repo(self, name):
         "Checks to see whether the user already has the named repo."
         cmd = f"gh repo list --json name --limit 10000"
